@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
@@ -41,6 +41,7 @@ from rattail.core import Object
 from rattail.gpc import GPC
 from rattail.db import Session
 from rattail.db import model
+from rattail.db.api.products import get_product_by_upc
 from rattail import enum
 from rattail.util import load_object
 from rattail.files import overwriting_move
@@ -559,35 +560,36 @@ class ChangesProcessor(Object):
         return product
 
     def process_price_del(self, row, session):
-        upc = row['F01']
+        """
+        Process a price deletion.
+        """
+        upc = row[u'F01']
         if not upc.isdigit():
-            log.warning("invalid upc: {0}".format(repr(upc)))
+            log.warning(u"invalid upc: {0}".format(repr(upc)))
             return
 
-        upc = GPC(upc, calc_check_digit='upc')
-
-        if row['F1000'] != 'PAL':
-            log.warning("target {0} not supported for {1}".format(
-                    repr(row['F1000']), repr(upc)))
+        if row[u'F1000'] != u'PAL':
+            log.debug(u"ignoring deletion on target {0} for upc: {1}".format(
+                    repr(row[u'F1000']), repr(row[u'F01'])))
             return
 
-        q = session.query(model.Product)
-        q = q.filter(model.Product.upc == upc)
-        product = q.first()
+        upc = GPC(upc, calc_check_digit=u'upc')
+        product = get_product_by_upc(session, upc)
         if not product:
             return
 
-        q = session.query(model.ProductPrice)
-        q = q.filter(model.ProductPrice.product == product)
-        q = q.filter(model.ProductPrice.level == self.int_(row['F126']))
+        prices = session.query(model.ProductPrice)\
+            .filter(model.ProductPrice.product == product)\
+            .filter(model.ProductPrice.level == self.int_(row[u'F126']))
 
-        for price in q:
+        for price in prices:
+            log.debug(u"deleting level {0} price for upc: {1}".format(
+                    price.level, repr(row[u'F01'])))
             if product.regular_price is price:
                 product.regular_price = None
             if product.current_price is price:
                 product.current_price = None
-
-        q.delete(synchronize_session=False)
+            session.delete(price)
 
     def process_cost_chg(self, row, session):
         if row['F1000'] != 'PAL':
